#!/bin/sh
#
# create_config.sh
#
# Script to create config.h for compatibility with
# different asterisk versions.
#
# thanks to: Armin Schindler <armin@melware.de>
#

CONFIGFILE="config.h"
rm -f "$CONFIGFILE"

if [ $# -lt 1 ]; then
	echo >&2 "Missing argument"
	exit 1
fi

INCLUDEDIR="$1/asterisk"

if [ ! -d "$INCLUDEDIR" ]; then
	echo >&2 "Include directory '$INCLUDEDIR' does not exist"
	exit 1
fi

echo "Checking Asterisk version..."

echo "/*" >$CONFIGFILE
echo " * automatically generated by $0 `date`" >>$CONFIGFILE
echo " */" >>$CONFIGFILE
echo >>$CONFIGFILE
echo "#ifndef CHAN_SCCP_CONFIG_H" >>$CONFIGFILE
echo "#define CHAN_SCCP_CONFIG_H" >>$CONFIGFILE
echo >>$CONFIGFILE

if grep -q "struct ast_channel_tech" $INCLUDEDIR/channel.h; then
	echo "#define CS_AST_HAS_TECH_PVT" >>$CONFIGFILE
	echo " * found 'struct ast_channel_tech'"
else
	echo "#undef CS_AST_HAS_TECH_PVT" >>$CONFIGFILE
	echo " * no 'struct ast_channel_tech', using old pvt"
fi

if grep -q "ast_bridged_channel" $INCLUDEDIR/channel.h; then
        echo "#define CS_AST_HAS_BRIDGED_CHANNEL" >>$CONFIGFILE
        echo " * found 'ast_bridged_channel'"
fi

if grep -q "struct ast_callerid" $INCLUDEDIR/channel.h; then
	echo "#define CS_AST_CHANNEL_HAS_CID" >>$CONFIGFILE
	echo " * found 'struct ast_callerid'"
else
	echo "#undef CS_AST_CHANNEL_HAS_CID" >>$CONFIGFILE
	echo " * no 'struct ast_callerid'"
fi

if grep -q "AST_MAX_CONTEXT" $INCLUDEDIR/channel.h; then
        echo " * found 'AST_MAX_CONTEXT'"
else
        echo "#define AST_MAX_CONTEXT AST_MAX_EXTENSION" >>$CONFIGFILE
        echo " * no 'AST_MAX_CONTEXT'"
fi

if grep -q "AST_CONTROL_HOLD" $INCLUDEDIR/frame.h; then
	echo "#define CS_AST_CONTROL_HOLD" >>$CONFIGFILE
	echo " * found 'AST_CONTROL_HOLD'"
else
	echo "#undef CS_AST_CONTROL_HOLD" >>$CONFIGFILE
	echo " * no 'AST_CONTROL_HOLD'"
fi

if grep -q "ast_config_load" $INCLUDEDIR/config.h; then
	echo " * found 'ast_config_load'"
else
	echo "#define ast_config_load(x) ast_load(x)" >>$CONFIGFILE
	echo "#define ast_config_destroy(x) ast_destroy(x)" >>$CONFIGFILE
	echo " * no 'ast_config_load'"
fi

if grep -rq "ast_copy_string" $INCLUDEDIR/; then
        echo "#define sccp_copy_string(x,y,z) ast_copy_string(x,y,z)" >>$CONFIGFILE
	echo " * found 'ast_copy_string'"
else
	echo "#define sccp_copy_string(x,y,z) strncpy(x,y,z - 1)" >>$CONFIGFILE
	echo " * no 'ast_copy_string'"
fi

if grep -q "AST_FLAG_MOH" $INCLUDEDIR/channel.h; then
	echo "#define CS_AST_HAS_FLAG_MOH" >>$CONFIGFILE
	echo " * found 'AST_FLAG_MOH'"
else
	echo "#define AST_FLAG_MOH              (1 << 6)" >>$CONFIGFILE
	echo " * no 'AST_FLAG_MOH'"
fi

if [ -e "$INCLUDEDIR/strings.h" ]; then
        echo "#define CS_AST_HAS_STRINGS" >>$CONFIGFILE
        echo " * found strings.h"
fi

if grep -q "ast_app_has_voicemail.*folder" $INCLUDEDIR/app.h; then
        echo "#define CS_AST_HAS_NEW_VOICEMAIL" >>$CONFIGFILE
	echo " * found new ast_app_has_voicemail"
fi

if grep -q "ast_get_hint.*name" $INCLUDEDIR/pbx.h; then
        echo "#define CS_AST_HAS_NEW_HINT" >>$CONFIGFILE
        echo " * found new ast_get_hint"
fi

echo "" >>$CONFIGFILE
echo "#endif /* CHAN_CAPI_CONFIG_H */" >>$CONFIGFILE
echo "" >>$CONFIGFILE

echo "config.h complete."
exit 0
