/*
 * (SCCP*)
 *
 * An implementation of Skinny Client Control Protocol (SCCP)
 *
 * Sergio Chersovani (mlists@c-net.it)
 *
 * Reworked, but based on chan_sccp code.
 * The original chan_sccp driver that was made by Zozo which itself was derived from the chan_skinny driver.
 * Modified by Jan Czmok and Julien Goodwin
 *
 * This program is free software and may be modified and
 * distributed under the terms of the GNU Public License.
 */

#include "chan_sccp.h"
#include "sccp_actions.h"
#include "sccp_utils.h"
#include "sccp_device.h"
#include "sccp_pbx.h"
#include "sccp_line.h"
#include "sccp_channel.h"

/* Kills a line's channels. */
/* Called with a lock on l->lock */
void sccp_line_kill(sccp_line_t * l) {
  sccp_channel_t * c = l->channels;
  while (c) {
    sccp_channel_t * t = c->next;
    sccp_channel_delete(c);
    c = t;
  }
}

void sccp_line_delete_nolock(sccp_line_t * l) {
	/* remove from the global lines list */
	if (l->next) { /* not the last one */
		ast_mutex_lock(&l->next->lock);
		l->next->prev = l->prev;
		ast_mutex_unlock(&l->next->lock);
	}
	if (l->prev) { /* not the first one */
		ast_mutex_lock(&l->prev->lock);
		l->prev->next = l->next;
		ast_mutex_unlock(&l->prev->lock);
	} else { /* the first one */
		ast_mutex_lock(&GLOB(lines_lock));
		GLOB(lines) = l->next;
		ast_mutex_unlock(&GLOB(lines_lock));
	}

	/* remove the line from the device lines list */
	if (l->next_on_device) { /* not the last one */
		ast_mutex_lock(&l->next_on_device->lock);
		l->next_on_device->prev_on_device = l->prev_on_device;
		ast_mutex_unlock(&l->next_on_device->lock);
	}
	if (l->prev_on_device) { /* not the first one */
		ast_mutex_lock(&l->prev_on_device->lock);
		l->prev_on_device->next_on_device = l->next_on_device;
		ast_mutex_unlock(&l->prev_on_device->lock);
	} else { /* the first one */
		ast_mutex_lock(&l->lock);
		l->device->lines = l->next_on_device;
		ast_mutex_unlock(&l->lock);
	}
	free(l);
}
